@@ -1,7 +1,7 @@
 import dataclasses
 import logging
 import irisml.core
-from typing import Union
+from typing import Union, Optional
 
 logger = logging.getLogger(__name__)
 
@@ -26,8 +26,8 @@ class Task(irisml.core.TaskBase):
 
     @dataclasses.dataclass
     class Config:
-        equal_allowed: bool = True
-        greater: bool = True
+        equal_allowed: Optional[bool] = True
+        greater: Optional[bool] = True
 
     def execute(self, inputs):
         if self.config.equal_allowed and inputs.val1 == inputs.val2:
