@@ -18,11 +18,13 @@ class Task(irisml.core.TaskBase):
 
     If val_dataset is provided, then it will be used as the validation dataset and the train_dataset will be used for training as-is.
 
+    If the dataset instance has 'get_targets(index)' method, it will be used for getting targets.
+
     Config:
         train_val_split (float): The ratio of the size of the train/val datasets.
         keep_class_distribution (bool): If true, tries to keep the class distribution.
     """
-    VERSION = '0.2.0'
+    VERSION = '0.2.1'
 
     @dataclasses.dataclass
     class Config:
@@ -80,7 +82,12 @@ class Task(irisml.core.TaskBase):
                 return [x]
             raise ValueError(f"Unexpected data label: {x=}, {type(x)=}")
 
-        image_class_indices = [(i, get_class(x[1])) for i, x in enumerate(dataset)]
+        if hasattr(dataset, 'get_targets'):
+            targets = [dataset.get_targets(i) for i in range(len(dataset))]
+        else:
+            targets = [x[1] for x in dataset]
+
+        image_class_indices = [(i, get_class(t)) for i, t in enumerate(targets)]
         random.shuffle(image_class_indices)
 
         train_indices = []
