@@ -14,7 +14,7 @@ class Task(irisml.core.TaskBase):
 
     A generated dataset returns (image:PIL.Image, target:int)
     """
-    VERSION = '0.1.0'
+    VERSION = '0.1.1'
 
     @dataclasses.dataclass
     class Config:
@@ -23,8 +23,9 @@ class Task(irisml.core.TaskBase):
 
     @dataclasses.dataclass
     class Outputs:
-        dataset: torch.utils.data.Dataset = None
-        num_classes: int = 0
+        dataset: torch.utils.data.Dataset
+        num_classes: int
+        class_names: typing.List[str]
 
     class FakeDataset(torch.utils.data.Dataset):
         def __init__(self, image_labels: typing.List[int], colors: typing.List[typing.Tuple[int, int, int]]):
@@ -58,4 +59,8 @@ class Task(irisml.core.TaskBase):
         colors = [(random.randint(0, 255), random.randint(0, 255), random.randint(0, 255)) for i in range(self.config.num_classes)]
         logger.debug(f"Generated labels: {colors}")
         dataset = Task.FakeDataset(labels, colors)
-        return self.Outputs(dataset, num_classes=self.config.num_classes)
+        class_names = [f'class_{i}' for i in range(self.config.num_classes)]
+        return self.Outputs(dataset, num_classes=self.config.num_classes, class_names=class_names)
+
+    def dry_run(self, inputs):
+        return self.execute(inputs)
