@@ -20,12 +20,12 @@ class Task(irisml.core.TaskBase):
     @dataclasses.dataclass
     class Inputs:
         conditions: List[bool]
-        vals: List[Union[float, int, str]]
-        default: Optional[Union[float, int, str]] = None
+        vals: List[Union[float, int, str, list]]
+        default: Optional[Union[float, int, str, list]] = None
 
     @dataclasses.dataclass
     class Outputs:
-        result: Union[float, int, str]
+        result: Union[float, int, str, list]
 
     def execute(self, inputs):
         assert len(inputs.conditions) == len(inputs.vals)
