@@ -44,7 +44,7 @@ class Task(irisml.core.TaskBase):
             blob_client.upload_blob(inputs.data)
         elif self.config.container_url:
             container_client = ContainerClient.from_container_url(self.config.container_url, credential=DefaultAzureCredential())
-            container_client.upload_blob(self.config.blob_path, inputs.data)
+            container_client.upload_blob(self.config.blob_path, inputs.data, max_concurrency=8, timeout=300)
 
         logger.info(f"Uploaded {len(inputs.data)} bytes.")
         return self.Outputs()
