@@ -17,6 +17,18 @@ class TestLoadStateDict(unittest.TestCase):
             Task(Task.Config(path=temp_file)).execute(inputs)
             self.assertTrue(self._is_equal_state_dict(fake_model.state_dict(), torch.load(temp_file)))
 
+    def test_fp16(self):
+        fake_model = torch.nn.Conv2d(3, 3, 3)
+
+        inputs = Task.Inputs(model=fake_model)
+        with tempfile.TemporaryDirectory() as temp_dir:
+            temp_file = pathlib.Path(temp_dir) / 'test.pth'
+
+            Task(Task.Config(path=temp_file, fp16=True)).execute(inputs)
+            saved = torch.load(temp_file)
+            self.assertEqual(saved['weight'].dtype, torch.float16)
+            self.assertEqual(saved['bias'].dtype, torch.float16)
+
     def test_no_parent_directory(self):
         fake_model = torch.nn.Conv2d(3, 3, 3)
 
