@@ -5,7 +5,8 @@ from irisml.tasks.switch_pick import Task
 
 class TestSwitchPick(unittest.TestCase):
     def test_switch_pick(self):
-        test_cases = [([True, True, False], [1, 2, 3], 1), ([False, True], [1, 2], 2), ([False, False], [1, 2], None), ([], [], None)]
+        test_cases = [([True, True, False], [1, 2, 3], 1), ([False, True], [1, 2], 2), ([False, False], [1, 2], None),
+                      ([], [], None), ([True], [[1, 2]], [1, 2]), ([False, True], [[1, 2], [3, 4]], [3, 4])]
         for conditions, vals, expect in test_cases:
             task = Task(Task.Config())
             result = task.execute(Task.Inputs(conditions, vals)).result
